<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ms">
<context>
    <name>CustomCommandOptDlg</name>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="112"/>
        <source>Name:</source>
        <translation>Nama:</translation>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="114"/>
        <source>Command:</source>
        <translation>Perintah:</translation>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="116"/>
        <source>Shortcuts:</source>
        <translation>Pintasan:</translation>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="127"/>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="128"/>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="205"/>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="211"/>
        <source>Required</source>
        <translation>Diperlukan</translation>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="154"/>
        <source>Add Command</source>
        <translation>Tambah Perintah</translation>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="160"/>
        <source>Edit Command</source>
        <translation>Sunting Perintah</translation>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="170"/>
        <source>Delete Command</source>
        <translation>Padam Perintah</translation>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="191"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Batal</translation>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="193"/>
        <source>Add</source>
        <comment>button</comment>
        <translation>Tambah</translation>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="195"/>
        <source>Save</source>
        <comment>button</comment>
        <translation>Simpan</translation>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="372"/>
        <source>Please enter a name</source>
        <translation>Sila masukkan satu nama</translation>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="386"/>
        <source>Please enter a command</source>
        <translation>Sila masukkan satu perintah</translation>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="436"/>
        <source>The name already exists,</source>
        <translation>Nama sudah wujud,</translation>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="437"/>
        <source>please input another one.</source>
        <translation>sila masukkan yang lain.</translation>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="618"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>CustomCommandPanel</name>
    <message>
        <location filename="../src/customcommand/customcommandpanel.cpp" line="212"/>
        <source>Add Command</source>
        <translation>Tambah Perintah</translation>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandpanel.cpp" line="216"/>
        <source>No commands yet</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>CustomCommandPlugin</name>
    <message>
        <location filename="../src/customcommand/customcommandplugin.cpp" line="50"/>
        <source>Custom commands</source>
        <translation>Perintah suai</translation>
    </message>
</context>
<context>
    <name>CustomCommandSearchRstPanel</name>
    <message>
        <location filename="../src/customcommand/customcommandsearchrstpanel.cpp" line="146"/>
        <source>Search</source>
        <translation>Gelintar</translation>
    </message>
</context>
<context>
    <name>CustomThemeSettingDialog</name>
    <message>
        <location filename="../src/views/customthemesettingdialog.cpp" line="236"/>
        <source>Custom Theme</source>
        <translation>Tema Suai</translation>
    </message>
    <message>
        <location filename="../src/views/customthemesettingdialog.cpp" line="260"/>
        <source>Style:</source>
        <translation>Gaya:</translation>
    </message>
    <message>
        <location filename="../src/views/customthemesettingdialog.cpp" line="264"/>
        <source>Light</source>
        <translation>Ringan</translation>
    </message>
    <message>
        <location filename="../src/views/customthemesettingdialog.cpp" line="269"/>
        <source>Dark</source>
        <translation>Gelap</translation>
    </message>
    <message>
        <location filename="../src/views/customthemesettingdialog.cpp" line="323"/>
        <source>Fore color:</source>
        <translation>Warna hadapan:</translation>
    </message>
    <message>
        <location filename="../src/views/customthemesettingdialog.cpp" line="330"/>
        <source>Back color:</source>
        <translation>Warna belakang:</translation>
    </message>
    <message>
        <location filename="../src/views/customthemesettingdialog.cpp" line="348"/>
        <source>Prompt PS1:</source>
        <translation>Prom PS1:</translation>
    </message>
    <message>
        <location filename="../src/views/customthemesettingdialog.cpp" line="352"/>
        <source>Prompt PS2:</source>
        <translation>Prom PS2:</translation>
    </message>
    <message>
        <location filename="../src/views/customthemesettingdialog.cpp" line="423"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Batal</translation>
    </message>
    <message>
        <location filename="../src/views/customthemesettingdialog.cpp" line="431"/>
        <source>Confirm</source>
        <comment>button</comment>
        <translation>Sahkan</translation>
    </message>
</context>
<context>
    <name>ListView</name>
    <message>
        <location filename="../src/views/listview.cpp" line="298"/>
        <source>Delete Server</source>
        <translation>Padam Pelayan</translation>
    </message>
    <message>
        <location filename="../src/views/listview.cpp" line="298"/>
        <location filename="../src/views/listview.cpp" line="492"/>
        <source>Are you sure you want to delete %1?</source>
        <translation>Anda pasti mahu memadam %1?</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="269"/>
        <location filename="../src/main/mainwindow.cpp" line="324"/>
        <source>New window</source>
        <translation>Tetingkap baharu</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="339"/>
        <source>Settings</source>
        <translation>Tetapan</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="755"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Batal</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="757"/>
        <source>Close</source>
        <comment>button</comment>
        <translation>Tutup</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1829"/>
        <source>Type path to download file</source>
        <translation>Taip laluan untuk muat turun fail</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="2135"/>
        <source>Custom Theme</source>
        <translation>Tema Suai</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/views/listview.cpp" line="304"/>
        <location filename="../src/views/listview.cpp" line="493"/>
        <location filename="../src/views/tabrenamedlg.cpp" line="236"/>
        <location filename="../src/common/utils.cpp" line="244"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Batal</translation>
    </message>
    <message>
        <location filename="../src/views/listview.cpp" line="305"/>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Padam</translation>
    </message>
    <message>
        <location filename="../src/views/listview.cpp" line="494"/>
        <location filename="../src/views/tabrenamedlg.cpp" line="241"/>
        <source>Confirm</source>
        <comment>button</comment>
        <translation>Sahkan</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="514"/>
        <location filename="../src/settings/settings_translation.cpp" line="109"/>
        <location filename="../src/main/mainwindow.cpp" line="1717"/>
        <source>Close workspace</source>
        <translation>Tutup ruang kerja</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="517"/>
        <location filename="../src/settings/settings_translation.cpp" line="105"/>
        <location filename="../src/main/mainwindow.cpp" line="1717"/>
        <source>Close other workspaces</source>
        <translation>Tutup ruang kerja lain</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="1177"/>
        <source>Could not find &quot;%1&quot;, starting &quot;%2&quot; instead. Please check your shell profile.</source>
        <translation>Tidak dapat mencari &quot;%1&quot;, memulakan &quot;%2&quot; sebagai ganti. Sila periksa profil shell anda.</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="1183"/>
        <source>Could not open &quot;%1&quot;, unable to run it</source>
        <translation>Tidak dapat membuka &quot;%1&quot;, gagal dijalankan</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="1185"/>
        <source>Could not find &quot;%1&quot;, unable to run it</source>
        <translation>Tidak dapat mencari &quot;%1&quot;, gagal dijalankan</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="1215"/>
        <source>Output has been suspended by pressing Ctrl+S. Pressing Ctrl+Q to resume.</source>
        <translation>Output telah ditangguh dengan menekan Ctrl+S. Tekan Ctrl+Q untuk menyambung semula.</translation>
    </message>
    <message>
        <location filename="../src/views/tabrenamewidget.cpp" line="132"/>
        <location filename="../src/settings/settings_translation.cpp" line="133"/>
        <source>Tab title format</source>
        <translation>Format tajuk tab</translation>
    </message>
    <message>
        <location filename="../src/views/tabrenamewidget.cpp" line="134"/>
        <location filename="../src/settings/settings_translation.cpp" line="135"/>
        <source>Remote tab title format</source>
        <translation>Format tajuk tab jauh</translation>
    </message>
    <message>
        <location filename="../src/views/tabrenamedlg.cpp" line="203"/>
        <location filename="../src/views/tabbar.cpp" line="504"/>
        <location filename="../src/settings/settings_translation.cpp" line="81"/>
        <location filename="../src/main/mainwindow.cpp" line="1735"/>
        <source>Rename title</source>
        <translation>Nama semula tajuk</translation>
    </message>
    <message>
        <location filename="../src/views/tabbar.cpp" line="498"/>
        <location filename="../src/main/mainwindow.cpp" line="1715"/>
        <source>Close tab</source>
        <translation>Tutup tab</translation>
    </message>
    <message>
        <location filename="../src/views/tabbar.cpp" line="501"/>
        <location filename="../src/main/mainwindow.cpp" line="1715"/>
        <source>Close other tabs</source>
        <translation>Tutup tab lain</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="33"/>
        <source>Copy on select</source>
        <translation>Salin ketika memilih</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="35"/>
        <source>Cursor blink</source>
        <translation>Kerlipan kursor</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="37"/>
        <source>Cursor style</source>
        <translation>Gaya kursor</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="39"/>
        <source>Scroll on keystroke</source>
        <translation>Tatal ketika ketukan kekunci</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="41"/>
        <source>Scroll on output</source>
        <translation>Tatal ketika output</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="43"/>
        <source>Hide Quake window after losing focus</source>
        <translation>Sembunyi tetingkap Quake setelah hilang fokus</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="45"/>
        <location filename="../src/main/service.cpp" line="159"/>
        <source>Blur background</source>
        <translation>Latar belakang kabur</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="47"/>
        <source>Use on starting</source>
        <translation>Guna ketika permulaan</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="49"/>
        <source>Font</source>
        <translation>Fon</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="51"/>
        <source>Font size</source>
        <translation>Saiz fon</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="53"/>
        <location filename="../src/main/service.cpp" line="182"/>
        <source>Opacity</source>
        <translation>Kelegapan</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="55"/>
        <source>Advanced</source>
        <translation>Lanjutan</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="57"/>
        <source>Cursor</source>
        <translation>Kursor</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="59"/>
        <source>Scroll</source>
        <translation>Tatal</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="61"/>
        <source>Window</source>
        <translation>Tetingkap</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="63"/>
        <source>Basic</source>
        <translation>Asas</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="65"/>
        <source>Interface</source>
        <translation>Antaramuka</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="67"/>
        <source>Shortcuts</source>
        <translation>Pintasan</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="69"/>
        <location filename="../src/main/mainwindow.cpp" line="1671"/>
        <source>Others</source>
        <translation>Lain-lain</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="71"/>
        <location filename="../src/main/terminalapplication.cpp" line="36"/>
        <location filename="../src/main/mainwindow.cpp" line="1669"/>
        <source>Terminal</source>
        <translation>Terminal</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="73"/>
        <source>Workspace</source>
        <translation>Ruang Kerja</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="75"/>
        <location filename="../src/main/mainwindow.cpp" line="1735"/>
        <source>Custom commands</source>
        <translation>Perintah suai</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="77"/>
        <location filename="../src/main/mainwindow.cpp" line="1735"/>
        <source>Display shortcuts</source>
        <translation>Papar pintasan</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="79"/>
        <location filename="../src/main/mainwindow.cpp" line="1735"/>
        <source>Remote management</source>
        <translation>Pengurusan jauh</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="83"/>
        <location filename="../src/main/mainwindow.cpp" line="1735"/>
        <source>Fullscreen</source>
        <translation>Skrin Penuh</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="85"/>
        <location filename="../src/main/mainwindow.cpp" line="1700"/>
        <source>Copy</source>
        <translation>Salin</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="87"/>
        <location filename="../src/main/mainwindow.cpp" line="1700"/>
        <source>Default size</source>
        <translation>Saiz lalai</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="89"/>
        <location filename="../src/main/mainwindow.cpp" line="1700"/>
        <source>Paste</source>
        <translation>Tampal</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="91"/>
        <source>Search</source>
        <translation>Gelintar</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="93"/>
        <location filename="../src/main/mainwindow.cpp" line="1700"/>
        <source>Select all</source>
        <translation>Pilih semua</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="95"/>
        <source>Jump to next command</source>
        <translation>Lompat ke perintah berikutnya</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="97"/>
        <source>Jump to previous command</source>
        <translation>Lompat ke perintah terdahulu</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="99"/>
        <location filename="../src/main/mainwindow.cpp" line="1700"/>
        <source>Zoom in</source>
        <translation>Zum masuk</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="101"/>
        <location filename="../src/main/mainwindow.cpp" line="1700"/>
        <source>Zoom out</source>
        <translation>Zum keluar</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="103"/>
        <source>Close other windows</source>
        <translation>Tutup tetingkap lain</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="107"/>
        <source>Close window</source>
        <translation>Tutup tetingkap</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="111"/>
        <location filename="../src/main/mainwindow.cpp" line="1716"/>
        <source>Horizontal split</source>
        <translation>Pisah mengufuk</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="113"/>
        <location filename="../src/main/mainwindow.cpp" line="1715"/>
        <source>New tab</source>
        <translation>Tab baharu</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="115"/>
        <location filename="../src/main/mainwindow.cpp" line="1715"/>
        <source>Next tab</source>
        <translation>Tab berikutnya</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="117"/>
        <location filename="../src/main/mainwindow.cpp" line="1715"/>
        <source>Previous tab</source>
        <translation>Tab terdahulu</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="119"/>
        <location filename="../src/main/mainwindow.cpp" line="1717"/>
        <source>Select left workspace</source>
        <translation>Pilih ruang kerja kiri</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="121"/>
        <location filename="../src/main/mainwindow.cpp" line="1716"/>
        <source>Select lower workspace</source>
        <translation>Pilih ruang kerja di bawah</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="123"/>
        <location filename="../src/main/mainwindow.cpp" line="1717"/>
        <source>Select right workspace</source>
        <translation>Pilih ruang kerja kanan</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="125"/>
        <location filename="../src/main/mainwindow.cpp" line="1716"/>
        <source>Select upper workspace</source>
        <translation>Pilih ruang kerja di atas</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="127"/>
        <location filename="../src/main/mainwindow.cpp" line="1716"/>
        <source>Vertical split</source>
        <translation>Pisah menegak</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="129"/>
        <location filename="../src/main/mainwindow.cpp" line="1700"/>
        <source>Find</source>
        <translation>Cari</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="131"/>
        <source>Tab titles</source>
        <translation>Tajuk tab</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="137"/>
        <location filename="../src/main/mainwindow.cpp" line="1718"/>
        <source>Go to tab 1</source>
        <translation>Pergi ke tab 1</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="139"/>
        <location filename="../src/main/mainwindow.cpp" line="1718"/>
        <source>Go to tab 2</source>
        <translation>Pergi ke tab 2</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="141"/>
        <location filename="../src/main/mainwindow.cpp" line="1718"/>
        <source>Go to tab 3</source>
        <translation>Pergi ke tab 3</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="143"/>
        <location filename="../src/main/mainwindow.cpp" line="1719"/>
        <source>Go to tab 4</source>
        <translation>Pergi ke tab 4</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="145"/>
        <location filename="../src/main/mainwindow.cpp" line="1719"/>
        <source>Go to tab 5</source>
        <translation>Pergi ke tab 5</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="147"/>
        <location filename="../src/main/mainwindow.cpp" line="1719"/>
        <source>Go to tab 6</source>
        <translation>Pergi ke tab 6</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="149"/>
        <location filename="../src/main/mainwindow.cpp" line="1720"/>
        <source>Go to tab 7</source>
        <translation>Pergi ke tab 7</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="151"/>
        <location filename="../src/main/mainwindow.cpp" line="1720"/>
        <source>Go to tab 8</source>
        <translation>Pergi ke tab 8</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="153"/>
        <location filename="../src/main/mainwindow.cpp" line="1720"/>
        <source>Go to tab 9</source>
        <translation>Pergi ke tab 9</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="155"/>
        <source>Disable flow control using Ctrl+S, Ctrl+Q</source>
        <translation>Lumpuhkan kawalan aliran menggunakan Ctrl+S, Ctrl+Q</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="157"/>
        <source>Shell profile</source>
        <translation>Profil Shell</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="517"/>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="379"/>
        <source>The name should be no more than 32 characters</source>
        <translation>Nama tidak lebih dari 32 aksara</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="583"/>
        <source>Select the private key file</source>
        <translation>Pilih fail kunci persendirian</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="587"/>
        <location filename="../src/main/mainwindow.cpp" line="1851"/>
        <location filename="../src/common/utils.cpp" line="133"/>
        <source>Select</source>
        <translation>Pilih</translation>
    </message>
    <message>
        <location filename="../src/main/terminalapplication.cpp" line="39"/>
        <source>Terminal is an advanced terminal emulator with workspace, multiple windows, remote management, quake mode and other features.</source>
        <translation>Terminal ialah sebuah emulator terminal lanjutan dengan ruang kerja, tetingkap berbilang, pengurusan jauh, mod Quake dan lain-lain fitur.</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1667"/>
        <source>Tabs</source>
        <translation>Tab</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1687"/>
        <source>Switch focus to &quot;+&quot; icon</source>
        <translation>Tukar fokus ke ikon &quot;+&quot;</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1716"/>
        <source>Select tab</source>
        <translation>Pilih tab</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1775"/>
        <location filename="../src/common/utils.cpp" line="148"/>
        <source>Select file to upload</source>
        <translation>Pilih fail untuk dimuat naik</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1782"/>
        <location filename="../src/common/utils.cpp" line="153"/>
        <source>Upload</source>
        <translation>Muat naik</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1845"/>
        <location filename="../src/common/utils.cpp" line="127"/>
        <source>Select a directory to save the file</source>
        <translation>Pilih satu direktori untuk menyimpan fail</translation>
    </message>
    <message>
        <location filename="../src/main/service.cpp" line="403"/>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="621"/>
        <location filename="../src/common/utils.cpp" line="254"/>
        <source>please set another one.</source>
        <translation>sila tetapkan yang lain.</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="173"/>
        <location filename="../src/common/utils.cpp" line="207"/>
        <source>Close this terminal?</source>
        <translation>Tutup terminal ini?</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="174"/>
        <location filename="../src/common/utils.cpp" line="208"/>
        <source>There is still a process running in this terminal. Closing the terminal will kill it.</source>
        <translation>Masih terdapat satu proses berjalan dalam terminal ini. Penutupan terminal akan mematikannya.</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="178"/>
        <location filename="../src/common/utils.cpp" line="212"/>
        <source>There are still %1 processes running in this terminal. Closing the terminal will kill all of them.</source>
        <translation>Masih terdapat %1 proses berjalan dalam terminal ini. Penutupan terminal akan mematikan semuanya.</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="183"/>
        <location filename="../src/common/utils.cpp" line="203"/>
        <source>Close this window?</source>
        <translation>Tutup tetingkap ini?</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="184"/>
        <location filename="../src/common/utils.cpp" line="204"/>
        <source>There are still processes running in this window. Closing the window will kill all of them.</source>
        <translation>Masih terdapat proses berjalan dalam terminal ini. Penutupan terminal akan mematikan semuanya.</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="221"/>
        <source>Programs are still running in terminal</source>
        <translation>Program masih lagu berjalan di dalam terminal</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="221"/>
        <source>Are you sure you want to uninstall it?</source>
        <translation>Anda pasti mahu menyahpasangkannya?</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="234"/>
        <location filename="../src/common/utils.cpp" line="238"/>
        <source>Are you sure you want to uninstall this application?</source>
        <translation>Anda pasti mahu menyahpasang aplikasi ini?</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="235"/>
        <location filename="../src/common/utils.cpp" line="239"/>
        <source>You will not be able to use Terminal any longer.</source>
        <translation>Anda tidak dapat menggunakan Terminal lagi.</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="245"/>
        <location filename="../src/common/utils.cpp" line="289"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="323"/>
        <source>Set the work directory</source>
        <translation>Tetapkan direktori kerja</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="326"/>
        <source>Set the window mode on starting</source>
        <translation>Tetapkan mod tetingkap ketika permulaan</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="329"/>
        <source>Execute a command in the terminal</source>
        <translation>Lakukan satu perintah di dalam terminal</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="332"/>
        <source>Run script string in the terminal</source>
        <translation>Jalankan rentetan skrip di dalam terminal</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="335"/>
        <source>Run in quake mode</source>
        <translation>Jalankan dalam mod quake</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="338"/>
        <source>Keep terminal open when command finishes</source>
        <translation>Biarkan terminal terbuka walaupun perintah selesai</translation>
    </message>
</context>
<context>
    <name>RemoteManagementPanel</name>
    <message>
        <location filename="../src/remotemanage/remotemanagementpanel.cpp" line="201"/>
        <source>Add Server</source>
        <translation>Tambah Pelayan</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/remotemanagementpanel.cpp" line="205"/>
        <source>No servers yet</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>RemoteManagementPlugin</name>
    <message>
        <location filename="../src/remotemanage/remotemanagementplugn.cpp" line="90"/>
        <source>Remote management</source>
        <translation>Pengurusan jauh</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/remotemanagementplugn.cpp" line="216"/>
        <source>Make sure that rz and sz commands have been installed in the server before right clicking to upload and download files.</source>
        <translation>Pastikan perintah rz dan sz telah dipasang dalam pelayan sebelum mengklik kanan untuk muat naik dan muat turun fail.</translation>
    </message>
</context>
<context>
    <name>RemoteManagementSearchPanel</name>
    <message>
        <location filename="../src/remotemanage/remotemanagementsearchpanel.cpp" line="225"/>
        <source>Search</source>
        <translation>Gelintar</translation>
    </message>
</context>
<context>
    <name>ServerConfigOptDlg</name>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="70"/>
        <source>Advanced options</source>
        <translation>Pilihan lanjutan</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="108"/>
        <source>Add Server</source>
        <translation>Tambah Pelayan</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="144"/>
        <source>Server name:</source>
        <translation>Nama pelayan:</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="146"/>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="156"/>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="184"/>
        <source>Required</source>
        <translation>Diperlukan</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="154"/>
        <source>Address:</source>
        <translation>Alamat:</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="161"/>
        <source>Port:</source>
        <translation>Port:</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="182"/>
        <source>Username:</source>
        <translation>Nama Pengguna:</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="189"/>
        <source>Password:</source>
        <translation>Kata Laluan:</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="195"/>
        <source>Certificate:</source>
        <translation>Sijil:</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="211"/>
        <source>Group:</source>
        <translation>Kumpulan:</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="217"/>
        <source>Path:</source>
        <translation>Laluan:</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="223"/>
        <source>Command:</source>
        <translation>Perintah:</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="229"/>
        <source>Encoding:</source>
        <translation>Pengekodan:</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="235"/>
        <source>Backspace key:</source>
        <translation>Kekunci Backspace:</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="241"/>
        <source>Delete key:</source>
        <translation>Kekunci delete:</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="247"/>
        <source>Delete server</source>
        <translation>Padam pelayan</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="261"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Batal</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="262"/>
        <source>Add</source>
        <comment>button</comment>
        <translation>Tambah</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="266"/>
        <source>Edit Server</source>
        <translation>Sunting Pelayan</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="267"/>
        <source>Save</source>
        <comment>button</comment>
        <translation>Simpan</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="511"/>
        <source>Please enter a server name</source>
        <translation>Sila masukkan nama pelayan</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="524"/>
        <source>Please enter an IP address</source>
        <translation>Sila masukkan alamat IP</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="529"/>
        <source>Please enter a port</source>
        <translation>Sila masukkan port</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="535"/>
        <source>Please enter a username</source>
        <translation>Sila masukkan nama pengguna</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="549"/>
        <source>The server name already exists,</source>
        <translation>Nama pelayan sudah wujud,</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="550"/>
        <source>please input another one. </source>
        <translation>sila masukkan yang lain.</translation>
    </message>
</context>
<context>
    <name>Service</name>
    <message>
        <location filename="../src/main/service.cpp" line="399"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <location filename="../src/settings/settings.cpp" line="143"/>
        <source>Normal window</source>
        <translation>Tetingkap biasa</translation>
    </message>
    <message>
        <location filename="../src/settings/settings.cpp" line="143"/>
        <source>Split screen</source>
        <translation>Pisah skrin</translation>
    </message>
    <message>
        <location filename="../src/settings/settings.cpp" line="143"/>
        <source>Maximum</source>
        <translation>Maksimum</translation>
    </message>
    <message>
        <location filename="../src/settings/settings.cpp" line="143"/>
        <source>Fullscreen</source>
        <translation>Skrin Penuh</translation>
    </message>
</context>
<context>
    <name>ShortcutManager</name>
    <message>
        <location filename="../src/settings/shortcutmanager.cpp" line="283"/>
        <location filename="../src/settings/shortcutmanager.cpp" line="292"/>
        <source>The shortcut %1 is invalid, </source>
        <translation>Pintasan %1 tidak sah,</translation>
    </message>
    <message>
        <location filename="../src/settings/shortcutmanager.cpp" line="299"/>
        <location filename="../src/settings/shortcutmanager.cpp" line="306"/>
        <location filename="../src/settings/shortcutmanager.cpp" line="312"/>
        <source>The shortcut %1 was already in use, </source>
        <translation>Pintasan %1 sudah digunakan,</translation>
    </message>
</context>
<context>
    <name>TabRenameWidget</name>
    <message>
        <location filename="../src/views/tabrenamewidget.cpp" line="60"/>
        <source>Insert</source>
        <translation>Sisip</translation>
    </message>
    <message>
        <location filename="../src/views/tabrenamewidget.cpp" line="95"/>
        <location filename="../src/views/tabrenamewidget.cpp" line="109"/>
        <source>username: %u</source>
        <translation>nama pengguna: %u</translation>
    </message>
    <message>
        <location filename="../src/views/tabrenamewidget.cpp" line="95"/>
        <source>username@: %U</source>
        <translation>nama pengguna@: %U</translation>
    </message>
    <message>
        <location filename="../src/views/tabrenamewidget.cpp" line="95"/>
        <source>remote host: %h</source>
        <translation>hos jauh: %h</translation>
    </message>
    <message>
        <location filename="../src/views/tabrenamewidget.cpp" line="96"/>
        <location filename="../src/views/tabrenamewidget.cpp" line="108"/>
        <source>session number: %#</source>
        <translation>nombor sesi: %#</translation>
    </message>
    <message>
        <location filename="../src/views/tabrenamewidget.cpp" line="96"/>
        <location filename="../src/views/tabrenamewidget.cpp" line="110"/>
        <source>title set by shell: %w</source>
        <translation>Set tajuk oleh shell: %w</translation>
    </message>
    <message>
        <location filename="../src/views/tabrenamewidget.cpp" line="107"/>
        <source>program name: %n</source>
        <translation>nama program: %n</translation>
    </message>
    <message>
        <location filename="../src/views/tabrenamewidget.cpp" line="107"/>
        <source>current directory (short): %d</source>
        <translation>direktori semasa (singkatan): %d</translation>
    </message>
    <message>
        <location filename="../src/views/tabrenamewidget.cpp" line="108"/>
        <source>current directory (long): %D</source>
        <translation>direktori semasa (panjang): %D</translation>
    </message>
    <message>
        <location filename="../src/views/tabrenamewidget.cpp" line="109"/>
        <source>local host: %h</source>
        <translation>hos setempat: %h</translation>
    </message>
</context>
<context>
    <name>TermWidget</name>
    <message>
        <location filename="../src/views/termwidget.cpp" line="483"/>
        <source>Copy</source>
        <translation>Salin</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="486"/>
        <source>Paste</source>
        <translation>Tampal</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="495"/>
        <source>Open</source>
        <translation>Buka</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="499"/>
        <source>Open in file manager</source>
        <translation>Buka dalam pengurus fail</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="508"/>
        <location filename="../src/views/termwidget.cpp" line="567"/>
        <source>Horizontal split</source>
        <translation>Pisah mengufuk</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="511"/>
        <location filename="../src/views/termwidget.cpp" line="567"/>
        <source>Vertical split</source>
        <translation>Pisah menegak</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="521"/>
        <location filename="../src/views/termwidget.cpp" line="567"/>
        <source>New tab</source>
        <translation>Tab baharu</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="528"/>
        <source>Exit fullscreen</source>
        <translation>Keluar dari skrin penuh</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="530"/>
        <source>Fullscreen</source>
        <translation>Skrin Penuh</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="533"/>
        <source>Find</source>
        <translation>Cari</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="537"/>
        <source>Search</source>
        <translation>Gelintar</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="547"/>
        <source>Encoding</source>
        <translation>Pengekodan</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="549"/>
        <source>Custom commands</source>
        <translation>Perintah suai</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="551"/>
        <source>Remote management</source>
        <translation>Pengurusan jauh</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="555"/>
        <source>Upload file</source>
        <translation>Muat naik fail</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="556"/>
        <source>Download file</source>
        <translation>Muat turun fail</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="561"/>
        <source>Settings</source>
        <translation>Tetapan</translation>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <location filename="../src/common/utils.cpp" line="189"/>
        <location filename="../src/common/utils.cpp" line="223"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Batal</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="191"/>
        <source>Close</source>
        <comment>button</comment>
        <translation>Tutup</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="224"/>
        <location filename="../src/common/utils.cpp" line="256"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>OK</translation>
    </message>
</context>
</TS>